from datacite_api import Dois
import click

import logging


logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

formatter = logging.Formatter('%(asctime)s:%(name)s:%(message)s')
file_handler = logging.FileHandler('run.log')
file_handler.setFormatter(formatter)
logger.addHandler(file_handler)

print("Working on a DOI ...")
print("Registering")
@click.command()
@click.argument('password_file', type=click.File('r'))
@click.option("-do", "--doi", help="creating a DOI")
@click.option("-y", "--yaml_data", help="updating a DOI")
@click.option("-c", "--create", is_flag=True, help="creating a DOI")
@click.option("-u", "--update", is_flag=True, help="updating a DOI")
@click.option("-d", "--delete", is_flag=True, help="deleting a DOI")
@click.option("-r", "--register", is_flag=True, help="registering a DOI")
@click.option("-f", "--findable", is_flag=True, help="making a DOI findable")
@click.option("-h", "--hide", is_flag=True, help="hiding a DOI")
def run(password_file,yaml_data,doi,create,update,delete,register,findable,hide):
    dc = Dois(password_file,yaml_data,doi)
    if create:
        dc.create_doi()
    elif update:
        dc.update_doi()
        logger.debug(password_file)
    elif register:
        logger.debug("Registering")
        dc.register_doi()

    elif findable:
        dc.set_findable()
    elif hide:
        dc.hide_doi()
    elif delete:
        dc.delete_doi()
run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import setuptools
from setuptools import setup

with open("README.md") as readme_file:
    readme = readme_file.read()

setup(
    name="saraorepository",
    version="0.0.0",
    description="Package to generate DOIs,create a webpage and upload data",
    long_description=readme + "\n\n",
    author="Sydil Kupa",
    author_email="skupa@ska.ac.za",
    url="https://github.com/ska-sa/katsdparchive/",
    packages=setuptools.find_packages(where="src", include=["saraorepository"]),
    package_dir={"": "src"},
    scripts=["scripts/doi.py"],
    include_package_data=True,
    license="None",
    zip_safe=False,
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ]
)
